package environment.rmi;

import environment.rmi.Detektor;
import environment.rmi.ObjectNotFoundException;
import environment.rmi.Signalgeber;
import java.rmi.Remote;
import java.rmi.RemoteException;

/**
 * Remote references of this class are used as a 'bootstrapping'-object.
 * After a reference to a remote object of this class 
 * has been retrieved using RMI registry, this reference can be used to 
 * retrieve object references for
 * {@link environment.rmi.Signalgeber}
 * and
 * {@link environment.rmi.Detektor}
 * .
 *
 * @author Andreas Metzger
 * @version 1.0
 */
public interface Verkehrsleitsystem extends Remote {
    
	/** Retrieves a remote object reference to a
	 * {@link environment.rmi.Signalgeber}
	 * object by name. 
	 * @param name Name of the object to be retrieved
	 * @exception ObjectNotFoundException Thrown if object with name was not found.
	 * @exception RemoteException All RMI objects throw this exception.
	 * @return Reference to object with specified name.
	 * found
	 */
	public Signalgeber getSignalgeber(String name) throws RemoteException, ObjectNotFoundException;

	/** Retrieves a remote object reference to a
	 * {@link environment.rmi.Detektor} 
	 * object by name.
	 * @param name Name of the object to be retrieved.
	 * @throws ObjectNotFoundException Thrown if object with name was not found
	 * @throws RemoteException All RMI objects throw this exception.
	 * @return Reference to object with specified name.
	 */
	public Detektor getDetektor(String name) throws RemoteException, ObjectNotFoundException;
}
